@@ -10,9 +10,9 @@ describe 'ovn::controller' do
       :ovn_bridge                  => 'br-int',
       :bridge_interface_mappings   => ['br-1:eth1'],
       :hostname                    => 'server1.example.com',
-      :mac_table_size              => 20000,
       :ovn_remote_probe_interval   => 30000,
       :ovn_openflow_probe_interval => 8,
+      :ovn_monitor_all             => true,
       :ovn_transport_zones         => ['tz1'],
       :enable_ovn_match_northd     => false,
       :ovn_chassis_mac_map         => ['physnet1:aa:bb:cc:dd:ee:ff',
@@ -76,6 +76,10 @@ describe 'ovn::controller' do
         :value   => params[:ovn_openflow_probe_interval],
       )
 
+      is_expected.to contain_vs_config('external_ids:ovn-monitor-all').with(
+        :value   => params[:ovn_monitor_all],
+      )
+
       is_expected.to contain_vs_config('external_ids:ovn-transport-zones').with(
         :value   => params[:ovn_transport_zones],
       )
@@ -104,6 +108,15 @@ describe 'ovn::controller' do
       )
     end
 
+    it 'clears mac_table_size' do
+      is_expected.to contain_exec('br-1').with(
+        :command => 'ovs-vsctl --timeout=5 remove Bridge br-1 other-config mac-table-size',
+        :path    => '/usr/sbin:/usr/bin:/sbin:/bin',
+        :onlyif  => [ 'ovs-vsctl br-exists br-1', 'ovs-vsctl get bridge br-1 other-config:mac-table-size'],
+        :require => [ 'Service[openvswitch]', 'Vs_bridge[br-1]' ],
+      )
+    end
+
     context 'when ovn_chassis_mac_map is a hash' do
       before :each do
         params.merge!({
@@ -119,6 +132,37 @@ describe 'ovn::controller' do
         )
       end
     end
+
+    context 'when setting mac_table_size' do
+      before :each do
+        params.merge!({
+          :mac_table_size => 20000
+        })
+      end
+
+      it 'configures mac_table_size' do
+        is_expected.to contain_exec('br-1').with(
+          :command => 'ovs-vsctl --timeout=5 set Bridge br-1 other-config:mac-table-size=20000',
+          :unless  => 'ovs-vsctl get bridge br-1 other-config:mac-table-size | grep -q -w 20000',
+          :path    => '/usr/sbin:/usr/bin:/sbin:/bin',
+          :onlyif  => [ 'ovs-vsctl br-exists br-1' ],
+          :require => [ 'Service[openvswitch]', 'Vs_bridge[br-1]' ],
+        )
+      end
+    end
+
+    context 'when manage_ovs_bridge is false' do
+      before :each do
+        params.merge!({
+          :manage_ovs_bridge => false,
+        })
+      end
+
+      it 'does not manage ovs bridge' do
+        is_expected.to_not contain_ovn__controller__bridge(params[:ovn_bridge_mappings].join(','))
+        is_expected.to_not contain_ovn__controller__port(params[:bridge_interface_mappings].join(','))
+      end
+    end
   end
 
   on_supported_os({
